/*
 * Package : grove
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 06/10/2020
 * Copyright :  S.Hamblett
 */

part of grove;

/// Command, data and font definitions for the Grove OLED SSD1327 based device.
class GroveOledSsd1327Definitions {
  /// Command codes
  static const oledData = 0x40;
  static const oledCmd = 0x80;
  static const displayCmdSetNormal = 0xA4;
  static const setColumnAddress = 0x15;
  static const setCommandLock = 0xfd;
  static const setCommandLockReset = 0x12;
  static const setDisplayOff = 0xae;
  static const setDisplayOn = 0xaf;
  static const setMuxRatio = 0xa8;
  static const setDisplayStartLine = 0xa1;
  static const setDisplayOffset = 0xa2;
  static const setRemap = 0xa0;
  static const functionSelectionA = 0xab;
  static const functionSelectionB = 0xd5;
  static const setContrast = 0x81;
  static const setPhaseLength = 0xb1;
  static const setFrontClock = 0xb3;
  static const setLinearLut = 0xb9;
  static const setPreChargeVoltage = 0xbc;
  static const setVcomh = 0xbe;
  static const setSecondPreChargePeriod = 0xb6;
  static const setNormalDisplay = 0xa4;
  static const deactivateScroll = 0x2e;
  static const setRowAddress = 0x75;
  static const displayModeInvert = 0xa7;
  static const displayModeOn = 0xa5;
  static const displayModeOff = 0xa6;
  static const displayModeNormal = 0xa4;

  /// Setting defaults
  static const startColumn = 8;
  static const startRowAddress = 0;
  static const endRowAddress = 95;
  static const startColumnAddress = 8;
  static const endColumnAddress = 55;
  static const defaultGrayLevel = 12;
  static const textRowStart = 0;
  static const textRowEnd = 12;
  static const textColumnStart = 0;
  static const textColumnEnd = 12;

  /// Command defaults
  static const muxRatio = 0x5f;
  static const displayStartLine = 0;
  static const displayOffset = 0x60;
  static const verticalMode = 0x46;
  static const vddInternal = 1;
  static const contrast = 0x53;
  static const phaseLength = 0x51;
  static const frontClockFrequency = 0x01;
  static const preChargeVoltage = 0x08;
  static const vcomh = 0x07;
  static const secondPreChargePeriod = 0x01;
  static const secondPrechargeAndVSL = 0X62;
  static const horizontalMode = 0x42;

  /// Display defaults
  static const maxPixels = 12 * 96; // Rows * pixels per line

  /// A basic font implementation
  static const List<List<int>> basicFont = <List<int>>[
    <int>[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x00, 0x5F, 0x00, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x00, 0x07, 0x00, 0x07, 0x00, 0x00, 0x00],
    <int>[0x00, 0x14, 0x7F, 0x14, 0x7F, 0x14, 0x00, 0x00],
    <int>[0x00, 0x24, 0x2A, 0x7F, 0x2A, 0x12, 0x00, 0x00],
    <int>[0x00, 0x23, 0x13, 0x08, 0x64, 0x62, 0x00, 0x00],
    <int>[0x00, 0x36, 0x49, 0x55, 0x22, 0x50, 0x00, 0x00],
    <int>[0x00, 0x00, 0x05, 0x03, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x1C, 0x22, 0x41, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x41, 0x22, 0x1C, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x08, 0x2A, 0x1C, 0x2A, 0x08, 0x00, 0x00],
    <int>[0x00, 0x08, 0x08, 0x3E, 0x08, 0x08, 0x00, 0x00],
    <int>[0x00, 0xA0, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x08, 0x08, 0x08, 0x08, 0x08, 0x00, 0x00],
    <int>[0x00, 0x60, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x20, 0x10, 0x08, 0x04, 0x02, 0x00, 0x00],
    <int>[0x00, 0x3E, 0x51, 0x49, 0x45, 0x3E, 0x00, 0x00],
    <int>[0x00, 0x00, 0x42, 0x7F, 0x40, 0x00, 0x00, 0x00],
    <int>[0x00, 0x62, 0x51, 0x49, 0x49, 0x46, 0x00, 0x00],
    <int>[0x00, 0x22, 0x41, 0x49, 0x49, 0x36, 0x00, 0x00],
    <int>[0x00, 0x18, 0x14, 0x12, 0x7F, 0x10, 0x00, 0x00],
    <int>[0x00, 0x27, 0x45, 0x45, 0x45, 0x39, 0x00, 0x00],
    <int>[0x00, 0x3C, 0x4A, 0x49, 0x49, 0x30, 0x00, 0x00],
    <int>[0x00, 0x01, 0x71, 0x09, 0x05, 0x03, 0x00, 0x00],
    <int>[0x00, 0x36, 0x49, 0x49, 0x49, 0x36, 0x00, 0x00],
    <int>[0x00, 0x06, 0x49, 0x49, 0x29, 0x1E, 0x00, 0x00],
    <int>[0x00, 0x00, 0x36, 0x36, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x00, 0xAC, 0x6C, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x08, 0x14, 0x22, 0x41, 0x00, 0x00, 0x00],
    <int>[0x00, 0x14, 0x14, 0x14, 0x14, 0x14, 0x00, 0x00],
    <int>[0x00, 0x41, 0x22, 0x14, 0x08, 0x00, 0x00, 0x00],
    <int>[0x00, 0x02, 0x01, 0x51, 0x09, 0x06, 0x00, 0x00],
    <int>[0x00, 0x32, 0x49, 0x79, 0x41, 0x3E, 0x00, 0x00],
    <int>[0x00, 0x7E, 0x09, 0x09, 0x09, 0x7E, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x49, 0x49, 0x49, 0x36, 0x00, 0x00],
    <int>[0x00, 0x3E, 0x41, 0x41, 0x41, 0x22, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x49, 0x49, 0x49, 0x41, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x09, 0x09, 0x09, 0x01, 0x00, 0x00],
    <int>[0x00, 0x3E, 0x41, 0x41, 0x51, 0x72, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F, 0x00, 0x00],
    <int>[0x00, 0x41, 0x7F, 0x41, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x20, 0x40, 0x41, 0x3F, 0x01, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x08, 0x14, 0x22, 0x41, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x40, 0x40, 0x40, 0x40, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x02, 0x0C, 0x02, 0x7F, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x04, 0x08, 0x10, 0x7F, 0x00, 0x00],
    <int>[0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x09, 0x09, 0x09, 0x06, 0x00, 0x00],
    <int>[0x00, 0x3E, 0x41, 0x51, 0x21, 0x5E, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x09, 0x19, 0x29, 0x46, 0x00, 0x00],
    <int>[0x00, 0x26, 0x49, 0x49, 0x49, 0x32, 0x00, 0x00],
    <int>[0x00, 0x01, 0x01, 0x7F, 0x01, 0x01, 0x00, 0x00],
    <int>[0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F, 0x00, 0x00],
    <int>[0x00, 0x1F, 0x20, 0x40, 0x20, 0x1F, 0x00, 0x00],
    <int>[0x00, 0x3F, 0x40, 0x38, 0x40, 0x3F, 0x00, 0x00],
    <int>[0x00, 0x63, 0x14, 0x08, 0x14, 0x63, 0x00, 0x00],
    <int>[0x00, 0x03, 0x04, 0x78, 0x04, 0x03, 0x00, 0x00],
    <int>[0x00, 0x61, 0x51, 0x49, 0x45, 0x43, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x41, 0x41, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x02, 0x04, 0x08, 0x10, 0x20, 0x00, 0x00],
    <int>[0x00, 0x41, 0x41, 0x7F, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x04, 0x02, 0x01, 0x02, 0x04, 0x00, 0x00],
    <int>[0x00, 0x80, 0x80, 0x80, 0x80, 0x80, 0x00, 0x00],
    <int>[0x00, 0x01, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x20, 0x54, 0x54, 0x54, 0x78, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x48, 0x44, 0x44, 0x38, 0x00, 0x00],
    <int>[0x00, 0x38, 0x44, 0x44, 0x28, 0x00, 0x00, 0x00],
    <int>[0x00, 0x38, 0x44, 0x44, 0x48, 0x7F, 0x00, 0x00],
    <int>[0x00, 0x38, 0x54, 0x54, 0x54, 0x18, 0x00, 0x00],
    <int>[0x00, 0x08, 0x7E, 0x09, 0x02, 0x00, 0x00, 0x00],
    <int>[0x00, 0x18, 0xA4, 0xA4, 0xA4, 0x7C, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x08, 0x04, 0x04, 0x78, 0x00, 0x00],
    <int>[0x00, 0x00, 0x7D, 0x00, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x80, 0x84, 0x7D, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x7F, 0x10, 0x28, 0x44, 0x00, 0x00, 0x00],
    <int>[0x00, 0x41, 0x7F, 0x40, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x7C, 0x04, 0x18, 0x04, 0x78, 0x00, 0x00],
    <int>[0x00, 0x7C, 0x08, 0x04, 0x7C, 0x00, 0x00, 0x00],
    <int>[0x00, 0x38, 0x44, 0x44, 0x38, 0x00, 0x00, 0x00],
    <int>[0x00, 0xFC, 0x24, 0x24, 0x18, 0x00, 0x00, 0x00],
    <int>[0x00, 0x18, 0x24, 0x24, 0xFC, 0x00, 0x00, 0x00],
    <int>[0x00, 0x00, 0x7C, 0x08, 0x04, 0x00, 0x00, 0x00],
    <int>[0x00, 0x48, 0x54, 0x54, 0x24, 0x00, 0x00, 0x00],
    <int>[0x00, 0x04, 0x7F, 0x44, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x3C, 0x40, 0x40, 0x7C, 0x00, 0x00, 0x00],
    <int>[0x00, 0x1C, 0x20, 0x40, 0x20, 0x1C, 0x00, 0x00],
    <int>[0x00, 0x3C, 0x40, 0x30, 0x40, 0x3C, 0x00, 0x00],
    <int>[0x00, 0x44, 0x28, 0x10, 0x28, 0x44, 0x00, 0x00],
    <int>[0x00, 0x1C, 0xA0, 0xA0, 0x7C, 0x00, 0x00, 0x00],
    <int>[0x00, 0x44, 0x64, 0x54, 0x4C, 0x44, 0x00, 0x00],
    <int>[0x00, 0x08, 0x36, 0x41, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x00, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x41, 0x36, 0x08, 0x00, 0x00, 0x00, 0x00],
    <int>[0x00, 0x02, 0x01, 0x01, 0x02, 0x01, 0x00, 0x00],
    <int>[0x00, 0x02, 0x05, 0x05, 0x02, 0x00, 0x00, 0x00]
  ];
}
